@@ -31,9 +31,7 @@
 #include "handybrl.h"
 #include "ecobrl.h"
 
-#ifdef BRLTTY_SUPPORT
 #include "ttybrl.h"
-#endif
 
 typedef struct
 {
@@ -68,26 +66,31 @@ BRLDevInfo   supported_devices[] = {
   {"HTMB8",   "HandyTech Modular 84"},
   {"ECO20",   "EcoBraille 20"},
   {"ECO40",   "EcoBraille 40"},
-  {"ECO80",   "EcoBraille 80"}
-
+  {"ECO80",   "EcoBraille 80"},
+  {"BRLTTY",  "BRLTTY's BrlAPI"},
  };
 
 static BRLDevice    *current_device = NULL;
 static guchar       *dots = NULL;
 static BRLEventProc client_event_proc = NULL;
+static gboolean	    enable_brltty = FALSE;
 
 /* Deviceless Functions */
 void
 brl_init()
 {
-    gint i;
+    gint i, cnt;
     gchar *brldev_key;
 
+    brltty_init ();
+    enable_brltty = brltty_check_if_present ();
     /* publish into GCONF the list of supported devices */
-    i = sizeof (supported_devices) / sizeof (BRLDevInfo);
-    SET_BRAILLE_CONFIG_DATA (BRAILLE_DEVICE_COUNT, CFGT_INT, &i);
+    cnt = G_N_ELEMENTS (supported_devices);
+    if (!enable_brltty)
+	cnt--;
+    SET_BRAILLE_CONFIG_DATA (BRAILLE_DEVICE_COUNT, CFGT_INT, &cnt);
 
-    for (i = 0; i < sizeof (supported_devices) / sizeof(BRLDevInfo); ++i)
+    for (i = 0; i < cnt; ++i)
     {
 	brldev_key = g_strdup_printf ("brldev_%d_ID", i);
 	SET_BRAILLE_CONFIG_DATA (brldev_key, CFGT_STRING, supported_devices[i].device_id);
@@ -97,8 +100,7 @@ brl_init()
 	SET_BRAILLE_CONFIG_DATA (brldev_key, CFGT_STRING, supported_devices[i].device_description);
 	g_free (brldev_key);
     }
-    
-    i = 0;
+
     SET_BRAILLE_CONFIG_DATA (BRAILLE_DEFAULT_DEVICE, CFGT_INT, &i);
 }
 
@@ -106,6 +108,7 @@ void
 brl_terminate()
 {
     brl_close_device();
+    brltty_terminate ();
 }
 
 /* Device Related Functions */
@@ -124,7 +127,7 @@ device_callback (BRLEventCode code,
 /* API Functions */
 gint
 brl_open_device (gchar        *device_name,
-	         gint         port,
+	         gchar         *port,
 		 BRLEventProc event_proc)
 {
     gint rv = 1;
@@ -163,9 +166,8 @@ brl_open_device (gchar        *device_name,
 	else if (strcmp("BRLTTY", device_name) == 0)
 	{			
 	    rv = 0;
-#ifdef BRLTTY_SUPPORT
-	    rv = brltty_brl_open_device (device_name, port, device_callback, current_device);			
-#endif
+	    if (enable_brltty)
+		rv = brltty_brl_open_device (device_name, port, device_callback, current_device);
 	}
 		
 	else if (strcmp("PB40", device_name) == 0)
