@@ -42,9 +42,9 @@ typedef enum
 /* Device data type */
 typedef struct
 {
-  guchar display_keys[32];
-  guchar front_keys[32];
-  guchar sensor_codes[32];
+  gchar display_keys[32];
+  gchar front_keys[32];
+  gchar sensor_codes[32];
   gulong pressed_front_keys;
   gulong pressed_display_keys;
 } ECODeviceData;
@@ -232,7 +232,7 @@ eco_brl_input_parser (gint new_val)
 {
     static BRLEventCode	bec;
     static BRLEventData	bed;
-    guchar sendbuffer[10];
+    gchar sendbuffer[10];
     gint n;
   
     if (!client_callback)
@@ -322,7 +322,7 @@ eco_brl_send_dots (guchar *dots,
     sendbuffer[count+4] = 0x03;
 
     /* We send to the device */
-    rv = brl_ser_send_data (sendbuffer, count+5, blocking);
+    rv = brl_ser_send_data ((gchar*)sendbuffer, count+5, blocking);
 
     return rv;
 }
