@@ -788,7 +788,7 @@ handy_brl_send_dots (guchar *dots,
     sendbuffer[handy_device_data.cell_count+4] = 0x16;
 	
     /* sending buffer to display */
-    rv = brl_ser_send_data (sendbuffer, handy_device_data.cell_count+5, blocking);
+    rv = brl_ser_send_data ((gchar*)sendbuffer, handy_device_data.cell_count+5, blocking);
 
     return rv;
 }
