@@ -26,7 +26,7 @@
 #include "braille.h"
 
 gint handy_brl_open_device (gchar               *device_name,
-			   gshort               port,
+			   gchar                *port,
 			   BRLDevCallback       device_callback,
 			   BRLDevice            *device);
 
