@@ -120,6 +120,7 @@ brlconf_setting_init (gboolean set_struct)
     value->attributes   	= brlconf_attributes_get ();
     value->translation_table	= brlconf_translation_table_get ();
     value->port_no		= brlconf_port_no_get ();
+    value->port			= brlconf_port_get ();
     value->status_cell		= brlconf_status_cell_get ();
     value->optical	 	= brlconf_optical_sensor_get ();
     value->position	 	= brlconf_position_sensor_get ();
@@ -226,6 +227,23 @@ brlconf_load_default_settings (Braille* braille)
     else
 	braille->port_no = DEFAULT_BRAILLE_PORT_NO;
 
+    value = gconf_client_get_default_from_schema (gnopernicus_client, 
+						CONFIG_PATH BRAILLE_KEY_PATH BRAILLE_PORT, 
+						NULL);
+    if (value)
+    {
+    	braille->port = g_strdup (gconf_value_get_string (value));
+	gconf_value_free (value);
+	value = NULL;
+    }
+    else
+    {
+	if (DEFAULT_BRAILLE_PORT)
+	    braille->port = g_strdup (DEFAULT_BRAILLE_PORT);
+	else
+	    braille->port = NULL;
+    }
+
     value = gconf_client_get_default_from_schema (gnopernicus_client, 
 						CONFIG_PATH BRAILLE_KEY_PATH BRAILLE_TRANSLATION, 
 						NULL);
@@ -371,6 +389,7 @@ brlconf_setting_set (const Braille *braille)
 {
     brlconf_cursor_style_set	(braille->cursor_style);
     brlconf_port_no_set		(braille->port_no);
+    brlconf_port_set		(braille->port);
     brlconf_attributes_set	(braille->attributes);
     brlconf_style_set		(braille->braille_style);
     brlconf_translation_table_set(braille->translation_table);
@@ -434,6 +453,15 @@ brlconf_port_no_set (gint port_no)
     }
 }
 
+void
+brlconf_port_set (const gchar *port)
+{
+    if (!gnopiconf_set_string (port, CONFIG_PATH BRAILLE_KEY_PATH BRAILLE_PORT))
+    {
+        sru_warning (_("Failed to set serial port : %s."), port);
+    }
+}
+
 
 void 
 brlconf_translation_table_set (const gchar *table)
@@ -568,7 +596,14 @@ gint
 brlconf_port_no_get (void)
 {
     return gnopiconf_get_int_with_default (CONFIG_PATH BRAILLE_KEY_PATH BRAILLE_PORT_NO, 
-					DEFAULT_BRAILLE_OPTICAL_SENSOR);
+					DEFAULT_BRAILLE_PORT_NO);
+}
+
+gchar* 
+brlconf_port_get (void)
+{
+    return gnopiconf_get_string_with_default (CONFIG_PATH BRAILLE_KEY_PATH BRAILLE_PORT, 
+					DEFAULT_BRAILLE_PORT);
 }
 
 gint 
@@ -595,8 +630,7 @@ brlconf_status_cell_get (void)
 static gint
 brlconf_default_device_get (void)
 {
-    return gnopiconf_get_int_with_default (CONFIG_PATH BRAILLE_KEY_PATH BRAILLE_DEFAULT_DEVICE, 
-					    DEFAULT_BRAILLE_DEVICE_INDEX);
+    return DEFAULT_BRAILLE_DEVICE_INDEX;
 }
 
 const gchar*
