@@ -80,6 +80,7 @@ const struct
     {N_("German"),		"de"},
     {N_("Spanish"),		"es"},
     {N_("Swedish"),		"sv"},
+    {N_("French"),		"fr"},
     {NULL,		NULL}
 };
 
@@ -335,6 +336,7 @@ brlui_braille_device_changeing (Braille *braille_setting)
     else
         braille_setting->port_no = -1;
     brlconf_port_no_set (braille_setting->port_no);
+    brlconf_port_set (braille_setting->port);
 }
 
 static void
@@ -346,15 +348,28 @@ brlui_braille_device_combo_changed (GtkWidget *entry,
     gdouble min_val, max_val;
 #endif 
     gboolean 	sensitivity;
+    gboolean	active_port_ck, active_port_et, active_port_no;
     sru_return_if_fail (braille_setting);    
     
     if (!strcmp (BRLTTY, gtk_entry_get_text (GTK_ENTRY (entry))))
 	sensitivity = FALSE;
     else
 	sensitivity = TRUE;
-	
-    gtk_widget_set_sensitive (GTK_WIDGET (lb_port), sensitivity);
-    gtk_widget_set_sensitive (GTK_WIDGET (cb_port), sensitivity);
+
+    active_port_ck = active_port_et = active_port_no = FALSE;
+    if (sensitivity)
+    {
+	active_port_ck = TRUE;
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_man_port)))
+	    active_port_et = TRUE;
+	else
+	    active_port_no = TRUE;
+    }
+
+    gtk_widget_set_sensitive (GTK_WIDGET (lb_port), active_port_no);
+    gtk_widget_set_sensitive (GTK_WIDGET (cb_port), active_port_no);
+    gtk_widget_set_sensitive (GTK_WIDGET (et_man_port), active_port_et);
+    gtk_widget_set_sensitive (GTK_WIDGET (ck_man_port), active_port_ck);
     
 #if 0    /* remove when it need to select the tty number */
     if (!strcmp (BRLTTY, gtk_entry_get_text (GTK_ENTRY (entry))))
@@ -410,10 +425,30 @@ static void
 brlui_braille_device_ck_man_port_toggled (GtkToggleButton *button, 
 					  gpointer user_data)
 {
-    gboolean state = gtk_toggle_button_get_active (button);
-    
-    gtk_widget_set_sensitive (et_man_port, state);
-    /* will be kept in gconf also & stuff */
+    if (GTK_WIDGET_SENSITIVE (button))
+    {
+	gboolean state = gtk_toggle_button_get_active (button);
+
+	gtk_widget_set_sensitive (et_man_port, state);
+	gtk_widget_set_sensitive (lb_port, !state);
+	gtk_widget_set_sensitive (cb_port, !state);
+	if (!state)
+	{
+	    g_free (braille_setting->port);
+	    braille_setting->port = g_strdup ("");
+	    gtk_entry_set_text (GTK_ENTRY (et_man_port), "");
+	}
+    }
+}
+static gboolean
+brlui_braille_device_et_man_port_changed (GtkWidget *widget,
+                                            GdkEventFocus *event,
+                                            gpointer user_data)
+{
+    g_free (braille_setting->port);
+    braille_setting->port = g_strdup (gtk_entry_get_text (GTK_ENTRY (et_man_port)));
+
+    return FALSE;
 }
 
 void 
@@ -439,6 +474,9 @@ brlui_set_handlers_braille_device (GladeXML *xml,
     glade_xml_signal_connect (xml,"on_ck_man_port_toggled",		
 			    GTK_SIGNAL_FUNC (brlui_braille_device_ck_man_port_toggled));
 
+    glade_xml_signal_connect (xml,"on_et_man_port_focus_out_event",		
+			    GTK_SIGNAL_FUNC (brlui_braille_device_et_man_port_changed));
+
     gtk_entry_set_editable (GTK_ENTRY (GTK_COMBO (cb_braille_device)->entry), FALSE);
 }
 
@@ -493,6 +531,7 @@ brlui_braille_device_value_add_to_widgets (Braille *braille_setting)
     gboolean found = FALSE, hasnone = FALSE;
     gint port;
     gchar *str, *error;
+    const gchar *dev;
 
     sru_return_val_if_fail (braille_setting, FALSE);    
     
@@ -503,8 +542,11 @@ brlui_braille_device_value_add_to_widgets (Braille *braille_setting)
     
     brlui_braille_device_set_to_combo (brldev_description_list);
 
+    dev = brlconf_return_active_device ();
+    if (!dev)
+	dev = _("<none>");
     gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (cb_braille_device)->entry), 
-			brlconf_return_active_device ());
+			dev);
 
     model = gtk_combo_box_get_model (GTK_COMBO_BOX (cb_port));
     if (!model)
@@ -533,6 +575,13 @@ brlui_braille_device_value_add_to_widgets (Braille *braille_setting)
     };
     if (found || hasnone)
 	gtk_combo_box_set_active_iter (GTK_COMBO_BOX (cb_port), &iter_found);
+    gtk_entry_set_text (GTK_ENTRY (et_man_port), braille_setting->port);
+    if (braille_setting->port && braille_setting->port[0])
+    {
+	gtk_widget_set_sensitive (GTK_WIDGET (lb_port), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (cb_port), FALSE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ck_man_port), TRUE);
+    }
 
     return TRUE;
 }
