@@ -154,91 +154,91 @@ struct poptOption poptopt[] =
 	 &gn_defaultmode, 	
 	 0, 
 	 "Launch in execution with default settings", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "enable-braille",	
 	 'b', 	
 	 POPT_ARG_NONE, 
 	 &gn_braille_enable,		
 	 0, 
 	 "enable braille service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-braille",	
 	 'B', 	
 	 POPT_ARG_NONE, 
 	 &gn_braille_disable,		
 	 0, 
 	 "enable braille service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "enable-speech",	
 	 's', 	
 	 POPT_ARG_NONE, 
 	 &gn_speech_enable,		
 	 0, 
 	 "enable speech service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-speech",	
 	 'S', 	
 	 POPT_ARG_NONE, 
 	 &gn_speech_disable,		
 	 0, 
 	 "disable speech service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "enable-magnifier",	
 	 'm', 	
 	 POPT_ARG_NONE, 
 	 &gn_magnifier_enable,		
 	 0, 
 	 "enable magnifier service",  
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-magnifier",	
 	 'M', 	
 	 POPT_ARG_NONE, 
 	 &gn_magnifier_disable,		
 	 0, 
 	 "disable magnifier service",  
-	 NULL
-	},
+ 	 NULL
+ 	},
 
-	{
+ 	{
 	 "enable-braille-monitor", 
 	 'o', 
 	 POPT_ARG_NONE, 
 	 &gn_braille_monitor_enable, 	
 	 0, 
 	 "enable braille monitor service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-braille-monitor", 
 	 'O', 
 	 POPT_ARG_NONE, 
 	 &gn_braille_monitor_disable, 	
 	 0, 
 	 "disable braille monitor service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "login", 
 	 'l', 
 	 POPT_ARG_NONE, 
 	 &gn_login, 	
 	 0, 
 	 "Used at login time", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "braille-port", 
 	 'p',   
 	 POPT_ARG_INT,  
@@ -246,8 +246,8 @@ struct poptOption poptopt[] =
 	 0, 
 	 "Serial port (ttyS)", 
 	 "ttyS[1..4]"
-	},
-	{
+ 	},
+ 	{
 	 "braille-device", 
 	 'e', 
 	 POPT_ARG_STRING, 
@@ -255,11 +255,11 @@ struct poptOption poptopt[] =
 	 0, 
 	 "Braille Device", 
 	 "DEVICE NAME"
-	},
-	{
+ 	},
+ 	{
 	 NULL, 0,     0, NULL, 0
-	}
-    };
+ 	}
+     };
 
 gint 
 main (gint argc,gchar *argv[])
@@ -310,19 +310,19 @@ main (gint argc,gchar *argv[])
 	argc++;
     }
     argv = argv1;
-
+    
     gnome_program_init ("gnopernicus", VERSION,
 			LIBGNOMEUI_MODULE,
 			argc, argv,
 			GNOME_PARAM_POPT_TABLE, poptopt,
 			GNOME_PARAM_HUMAN_READABLE_NAME, _("gnopernicus"),
 			GNOME_PARAM_APP_DATADIR, DATADIR,
-			NULL);
+			NULL);    
+
     sru_log_init ();
 
-/* FIXME the next line will be available only starting with gtk+ 2.6 */
-    /* gtk_window_set_default_icon_name ("gnopernicus"); */
-    gtk_window_set_default_icon_from_file (GNOPERNICUS_ICON, NULL);
+    g_set_application_name (_("Gnopernicus"));
+    gtk_window_set_default_icon_name ("gnopernicus");
 
     if (!gn_run_with_parameters ())
     {
@@ -387,7 +387,7 @@ main (gint argc,gchar *argv[])
     sru_log_terminate ();
     
     g_free (argv1);
-    
+
     return EXIT_SUCCESS;
 }
 
