@@ -28,7 +28,7 @@
 #include "srmag.h"
 #include "libsrconf.h"
 #include "brlinp.h"
-#include "libke.h"
+#include "src-kbd.h"
 #include "SREvent.h"
 #include "srctrl.h"
 #include "SRObject.h"
@@ -1023,7 +1023,7 @@ src_process_config_changed_for_magnifier (SRConfigStructure *config)
 	if (rv && src_use_speech)
 	{
 	    gchar *tmp;
-	    tmp = g_strdup_printf (crosswire ? _("crosshair on") : _("crosshair off"));
+	    tmp = g_strdup_printf (crosswire ? _("crosswire on") : _("crosswire off"));
 	    src_say_message (tmp);
 	    g_free (tmp);
 	}
@@ -1040,8 +1040,8 @@ src_process_config_changed_for_magnifier (SRConfigStructure *config)
 	if (rv && src_use_speech)
 	{
 	    gchar *tmp;
-	    tmp = g_strdup_printf (crosswire_clip ? _("crosshair clip on") :
-				                    _("crosshair clip off"));
+	    tmp = g_strdup_printf (crosswire_clip ? _("crosswire clip on") :
+				                    _("crosswire clip off"));
 	    src_say_message (tmp);
 	    g_free (tmp);
 	}
@@ -1059,7 +1059,7 @@ src_process_config_changed_for_magnifier (SRConfigStructure *config)
 	if (rv && src_use_speech)
 	{
 	    gchar *tmp;
-	    tmp = g_strdup_printf ("%s %d", _("crosshair size"), crosswire_size);
+	    tmp = g_strdup_printf ("%s %d", _("crosswire size"), crosswire_size);
     	    src_say_message (tmp);
 	    g_free (tmp);
 	}
@@ -1077,7 +1077,7 @@ src_process_config_changed_for_magnifier (SRConfigStructure *config)
 	if (rv && src_use_speech)
 	{
 	    gchar *tmp;
-	    tmp = g_strdup_printf ("%s %u", _("crosshair color"), crosswire_color);
+	    tmp = g_strdup_printf ("%s %u", _("crosswire color"), crosswire_color);
     	    src_say_message (tmp);
 	    g_free (tmp);
 	}
@@ -1363,7 +1363,7 @@ src_process_config_changed_for_control (SRConfigStructure *config)
     {
 	src_ctrl_terminate 	();
 	src_ctrl_init 		();
-	ke_config_changed	();
+	src_kbd_restart_cmds	();
     }
     /*src_update_key ();*/
 }
@@ -2440,7 +2440,7 @@ src_init(const gchar *mouse_tracking,
     src_srl_client = srl_add_client (&client);
 
     /* initialize keyboard */
-    ke_init ((KeyboardEchoCB)&src_event_sink);
+    src_kbd_init ((KeyboardEchoCB)&src_event_sink);
 
     src_layer = NULL;
     src_focused_sro = NULL;
@@ -2513,7 +2513,7 @@ src_terminate()
     srl_terminate ();
 
     /* terminate Keyboard */
-    ke_terminate();
+    src_kbd_terminate ();
 
     /* terminate Magnifier */
     if (src_use_magnifier)
@@ -2579,85 +2579,84 @@ main (gint argc,
     gint  	zoom_factor     = 0;
     gboolean 	invert 	    	= FALSE;
     gboolean    horiz_split     = FALSE;
-    gboolean 	login_enabled	= FALSE;    
+    gboolean 	login_enabled	= FALSE;        
 
-    
     struct poptOption poptopt[] = 
-    {		
-	{
+     {		
+ 	{
 	 "enable-braille",	
 	 'b', 	
 	 POPT_ARG_NONE, 
 	 &enable_braille,		
 	 0, 
 	 "Enable braille service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-braille",	
 	 'B', 	
 	 POPT_ARG_NONE, 
 	 &disable_braille,		
 	 0, 
 	 "Disable braille service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "enable-speech",	
 	 's', 	
 	 POPT_ARG_NONE, 
 	 &enable_speech,		
 	 0, 
 	 "Enable speech service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-speech",	
 	 'S', 	
 	 POPT_ARG_NONE, 
 	 &disable_speech,		
 	 0, 
 	 "Disable speech service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "enable-magnifier",	
 	 'm', 	
 	 POPT_ARG_NONE, 
 	 &enable_magnifier,		
 	 0, 
 	 "Enable magnifier service",  
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-magnifier",	
 	 'M', 	
 	 POPT_ARG_NONE, 
 	 &disable_magnifier,		
 	 0, 
 	 "Disable magnifier service",  
-	 NULL
-	},
+ 	 NULL
+ 	},
 
-	{
+ 	{
 	 "enable-braille-monitor", 
 	 'o', 
 	 POPT_ARG_NONE, 
 	 &enable_braille_monitor, 	
 	 0, 
 	 "Enable braille monitor service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-braille-monitor", 
 	 'O', 
 	 POPT_ARG_NONE, 
 	 &disable_braille_monitor, 	
 	 0, 
 	 "Disable braille monitor service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "braille-port", 
 	 'p',   
 	 POPT_ARG_INT,  
@@ -2665,8 +2664,8 @@ main (gint argc,
 	 0, 
 	 "Serial port (ttyS)", 
 	 "ttyS[1..4]"
-	},
-	{
+ 	},
+ 	{
 	 "braille-device", 
 	 'e', 
 	 POPT_ARG_STRING, 
@@ -2674,8 +2673,8 @@ main (gint argc,
 	 0, 
 	 "Braille Device", 
 	 "DEVICE NAME"
-	},
-	{
+ 	},
+ 	{
 	"settings-dir", 
 	 'c', 
 	 POPT_ARG_STRING, 
@@ -2683,8 +2682,8 @@ main (gint argc,
 	 0, 
 	 "Use gconf settings file", 
 	 "PATH"
-	},
-	{
+ 	},
+ 	{
 	"magnification-zoom", 
 	 'z', 
 	 POPT_ARG_INT, 
@@ -2692,8 +2691,8 @@ main (gint argc,
 	 0, 
 	 "Set magnification zoom level", 
 	 "[1..16]"
-	},
-	{
+ 	},
+ 	{
 	"magnification-invert", 
 	 'i', 
 	 POPT_ARG_NONE, 
@@ -2701,9 +2700,9 @@ main (gint argc,
 	 0, 
 	 "Magnification with reverse video", 
 	 ""
-	},
+ 	},
 	
-	{
+ 	{
 	"magnification-horizontal-split", 
 	 'u', 
 	 POPT_ARG_NONE, 
@@ -2711,9 +2710,9 @@ main (gint argc,
 	 0, 
 	 "Magnification with horizontal-split", 
 	 ""
-	},
+ 	},
 	
-	{
+ 	{
 	"login", 
 	 'l', 
 	 POPT_ARG_NONE, 
@@ -2721,8 +2720,8 @@ main (gint argc,
 	 0, 
 	 "Used at login time", 
 	 ""
-	},
-	{
+ 	},
+ 	{
 	"magnification-mouse-tracking", 
 	 't', 
 	 POPT_ARG_STRING, 
@@ -2730,9 +2729,9 @@ main (gint argc,
 	 0, 
 	 "How the mouse pushed the region", 
 	 "[CENTERED, PROPORTION, PUSH, NONE]"
-	},
+ 	},
 
-	{
+ 	{
 	"magnification-focus-tracking", 
 	 'f', 
 	 POPT_ARG_STRING, 
@@ -2740,11 +2739,11 @@ main (gint argc,
 	 0, 
 	 "How the focus pushed the region", 
 	 "[AUTO, CENTERED, NONE]"
-	},
-	{
+ 	},
+ 	{
 	 NULL, 0,     0, NULL, 0
-	}
-    };
+ 	}
+     };
     
 #ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, GNOPERNICUSLOCALEDIR);
@@ -2765,6 +2764,7 @@ main (gint argc,
 		    GNOME_PARAM_HUMAN_READABLE_NAME, _("srcore"),
 		    LIBGNOMEUI_PARAM_CRASH_DIALOG, FALSE,
 		    NULL);
+
     sru_log_init ();
     
     login_time = FALSE;	
@@ -2811,7 +2811,7 @@ main (gint argc,
     src_terminate ();
     
     sru_log_terminate ();
-    
+
     return EXIT_SUCCESS;
 }
 
