@@ -256,15 +256,15 @@ src_presentation_get_presentation_item_from_literal (xmlNode *node,
 {
     SRCPresentationItem *item;
 
-    sru_assert (xmlStrcmp (node->name, "literal") == 0);
+    sru_assert (xmlStrcmp (node->name, (const xmlChar*)"literal") == 0);
     
     item = src_presentation_item_new ();
     if (!item)
         return NULL;
 
     item->type  = SRC_PRESENTATION_INFO_TYPE_TEXT;
-    item->voice = g_strdup (xmlGetProp (node, "voice"));
-    item->data1 = g_strdup (xmlNodeGetContent (node));
+    item->voice = g_strdup ((gchar*)xmlGetProp (node, (const xmlChar*)"voice"));
+    item->data1 = g_strdup ((gchar*)xmlNodeGetContent (node));
     return item;
 }
 
@@ -275,14 +275,14 @@ src_presentation_get_presentation_item_from_dots (xmlNode *node,
 {
     SRCPresentationItem *item;
 
-    sru_assert (xmlStrcmp (node->name, "brdots") == 0);
+    sru_assert (xmlStrcmp (node->name, (const xmlChar*)"brdots") == 0);
     
     item = src_presentation_item_new ();
     if (!item)
         return NULL;
      
     item->type  = SRC_PRESENTATION_INFO_TYPE_SPECIAL;
-    item->data1 = g_strdup (xmlGetProp (node, "dots"));
+    item->data1 = g_strdup ((gchar*)xmlGetProp (node, (const xmlChar*)"dots"));
 
     return item;
 }
@@ -296,7 +296,7 @@ src_presentation_get_literal_node_lang (xmlNode *start,
 
     sru_assert (start && lang);
 
-    for (crt = start; crt && xmlStrcmp (crt->name, "literal") == 0; crt= crt->next)
+    for (crt = start; crt && xmlStrcmp (crt->name, (const xmlChar*)"literal") == 0; crt= crt->next)
     {
 	xmlChar *nlang = xmlNodeGetLang (crt);
 	if (nlang && xmlStrcmp (lang, nlang) == 0) /* perfect match */
@@ -323,7 +323,7 @@ src_presentation_get_from_true_false (xmlNode *node)
     if (node && node->xmlChildrenNode)
 	crt = src_presentation_get_literal_node_lang (node->xmlChildrenNode, (xmlChar*)srcp_get_lang ());
     if (crt)
-	return xmlNodeGetContent ((xmlNode*)crt);
+	return (gchar*)xmlNodeGetContent ((xmlNode*)crt);
     return NULL;
 }
 
@@ -334,7 +334,7 @@ src_presentation_get_presentation_item_from_conditional_ (xmlNode *node,
     xmlNode *crt;
     SRCPresentationItem *item;
     
-    sru_assert (xmlStrcmp (node->name, "conditional") == 0);
+    sru_assert (xmlStrcmp (node->name, (const xmlChar*)"conditional") == 0);
     
     item = src_presentation_item_new ();
     if (!item)
@@ -343,12 +343,12 @@ src_presentation_get_presentation_item_from_conditional_ (xmlNode *node,
     item->type  = SRC_PRESENTATION_INFO_TYPE_COND;
     for (crt = node->xmlChildrenNode; crt; crt= crt->next)
     {
-	if (xmlStrcmp (crt->name, "true") == 0)
+	if (xmlStrcmp (crt->name, (const xmlChar*)"true") == 0)
 	    item->data1 = src_presentation_get_from_true_false (crt);
-	else if (xmlStrcmp (crt->name, "false") == 0)
+	else if (xmlStrcmp (crt->name, (const xmlChar*)"false") == 0)
 	    item->data2 = src_presentation_get_from_true_false (crt);
     }
-    item->voice = g_strdup (xmlGetProp (node, "voice"));
+    item->voice = g_strdup ((gchar*)xmlGetProp (node, (const xmlChar*)"voice"));
 
     return item;
 }
@@ -361,7 +361,7 @@ src_presentation_get_presentation_item_from_conditional (xmlNode *node,
     
     item = src_presentation_get_presentation_item_from_conditional_ (node, device);
     item->type  = SRC_PRESENTATION_INFO_TYPE_COND;
-    item->info = src_presentation_get_item_type (xmlGetProp (node, "condition"));
+    item->info = src_presentation_get_item_type ((gchar*)xmlGetProp (node, (const xmlChar*)"condition"));
 
     return item;
 }
@@ -371,15 +371,16 @@ static SRCPresentationItem*
 src_presentation_get_presentation_item_from_conditional1 (xmlNode *node,
 						   const gchar *device)
 {
-    gchar *cond, *end, *condo;
+    xmlChar *cond, *end;
+    gchar *condo;
     SRCPresentationItem *item;
     
     item = src_presentation_get_presentation_item_from_conditional_ (node, device);
     item->type  = SRC_PRESENTATION_INFO_TYPE_COND1;
-    cond = xmlGetProp (node, "condition");
-    end = strstr (cond, "=1");
+    cond = xmlGetProp (node, (const xmlChar*)"condition");
+    end = (xmlChar*)strstr ((gchar*)cond, "=1");
     sru_assert (end);
-    condo = g_strndup (cond, end - cond);
+    condo = g_strndup ((gchar*)cond, end - cond);
     item->info = src_presentation_get_item_type (condo);
     g_free (condo);
     
@@ -392,7 +393,7 @@ src_presentation_get_presentation_item_from_attribute (xmlNode *node,
 {
     SRCPresentationItem *item;
 
-    sru_assert (xmlStrcmp (node->name, "attribute") == 0);
+    sru_assert (xmlStrcmp (node->name, (const xmlChar*)"attribute") == 0);
     
     item = src_presentation_item_new ();
     if (!item)
@@ -400,8 +401,8 @@ src_presentation_get_presentation_item_from_attribute (xmlNode *node,
 
     item->type  = SRC_PRESENTATION_INFO_TYPE_INFO;
     
-    item->info = src_presentation_get_item_type (xmlNodeGetContent (node));
-    item->voice = g_strdup (xmlGetProp (node, "voice"));
+    item->info = src_presentation_get_item_type ((gchar*)xmlNodeGetContent (node));
+    item->voice = g_strdup ((gchar*)xmlGetProp (node, (const xmlChar*)"voice"));
 
     return item;
 }
@@ -413,7 +414,7 @@ src_presentation_get_presentation_item_from_paranthesis (xmlNode *node,
     gchar *info;
     SRCPresentationItem *item;
 
-    sru_assert (xmlStrcmp (node->name, "attribute") == 0);
+    sru_assert (xmlStrcmp (node->name, (const xmlChar*)"attribute") == 0);
     
     item = src_presentation_item_new ();
     if (!item)
@@ -421,10 +422,10 @@ src_presentation_get_presentation_item_from_paranthesis (xmlNode *node,
 
     item->type  = SRC_PRESENTATION_INFO_TYPE_PARANTHESIS;
     
-    info = g_strdup (xmlNodeGetContent (node));
+    info = g_strdup ((gchar*)xmlNodeGetContent (node));
     info[strlen (info) - 1] = '\0';
     item->info = src_presentation_get_item_type (info + 1);
-    item->voice = g_strdup (xmlGetProp (node, "voice"));
+    item->voice = g_strdup ((gchar*)xmlGetProp (node, (const xmlChar*)"voice"));
     g_free (info);
 
     return item;
@@ -444,7 +445,7 @@ src_presentation_get_presentation_item_from_children (xmlNode *node,
     SRCPresentationItem *item;
     SRCPresentationItem **item1;
 
-    sru_assert (xmlStrcmp (node->name, "children") == 0);
+    sru_assert (xmlStrcmp (node->name, (const xmlChar*)"children") == 0);
 
     item = src_presentation_item_new ();
     if (!item)
@@ -455,7 +456,7 @@ src_presentation_get_presentation_item_from_children (xmlNode *node,
     src_presentation_get_presentation_items_from_node (node, device, &item1);
     
     item->data1 = item1;
-    item->data2 = g_strdup (xmlGetProp (node, "sep"));
+    item->data2 = g_strdup ((gchar*)xmlGetProp (node, (const xmlChar*)"sep"));
 
     return item;
 }
@@ -476,36 +477,36 @@ src_presentation_get_presentation_items_from_node (xmlNode *node,
     {
 	SRCPresentationItem *item = NULL;
 	xmlNode *ant;
-	if (xmlStrcmp (crt->name, "literal") == 0)
+	if (xmlStrcmp (crt->name, (const xmlChar*)"literal") == 0)
 	{
 	    const xmlNode *literal = src_presentation_get_literal_node_lang (crt, (xmlChar*)srcp_get_lang ());
 	    if (literal)
 		item = src_presentation_get_presentation_item_from_literal ((xmlNode*)literal, device);
-	    for (ant = crt ; ant && xmlStrcmp (ant->name, "literal") == 0; ant = ant->next)
+	    for (ant = crt ; ant && xmlStrcmp (ant->name, (const xmlChar*)"literal") == 0; ant = ant->next)
 		crt = ant;
 	}
-	else if (xmlStrcmp (crt->name, "brdots") == 0)
+	else if (xmlStrcmp (crt->name, (const xmlChar*)"brdots") == 0)
 	    item = src_presentation_get_presentation_item_from_dots (crt, device);
-	else if (xmlStrcmp (crt->name, "conditional") == 0)
+	else if (xmlStrcmp (crt->name, (const xmlChar*)"conditional") == 0)
 	{
-	    gchar *cond, *e1;
-	    cond = xmlGetProp (crt, "condition");
-	    e1 = strstr (cond, "=1");
+	    xmlChar *cond, *e1;
+	    cond = xmlGetProp (crt, (const xmlChar*)"condition");
+	    e1 = (xmlChar*)strstr ((gchar*)cond, "=1");
 	    if (e1)
 		item = src_presentation_get_presentation_item_from_conditional1 (crt, device);
 	    else
 		item = src_presentation_get_presentation_item_from_conditional (crt, device);
 	}
-	else if (xmlStrcmp (crt->name, "attribute") == 0)
+	else if (xmlStrcmp (crt->name, (const xmlChar*)"attribute") == 0)
 	{
-	    gchar *attr;
+	    xmlChar *attr;
 	    attr = xmlNodeGetContent (crt);
 	    if (attr[0] == '(')
 		item = src_presentation_get_presentation_item_from_paranthesis (crt, device);
 	    else
 		item = src_presentation_get_presentation_item_from_attribute (crt, device);
 	}
-	else if (xmlStrcmp (crt->name, "children") == 0)
+	else if (xmlStrcmp (crt->name, (const xmlChar*)"children") == 0)
 	    item = src_presentation_get_presentation_item_from_children (crt, device);
 	else 
 	    sru_warning ("unknown \"%s\" tag", crt->name);
@@ -529,6 +530,11 @@ src_presentation_get_presentation_items_from_node (xmlNode *node,
 	(*presentation)[i] = NULL;
 	g_slist_free (list);
     }
+    else
+    {
+    	*presentation = g_new (SRCPresentationItem *,  1);
+	(*presentation)[0] = NULL;
+    }
 
     return *presentation ? TRUE : FALSE;    
 }
@@ -587,7 +593,7 @@ src_presentation_find_chunk_for_braille (const gchar *role,
     *presentation = (SRCPresentationItem **)src_presentation_find_chunk_in_hash_table (
 			    src_presentation_chunks_braille, role, event);
 
-    return *presentation ? TRUE : FALSE;
+    return *presentation && (*presentation)[0] ? TRUE : FALSE;
 }
 
 
@@ -603,7 +609,7 @@ src_presentation_find_chunk_for_speech (const gchar *role,
     *presentation = (SRCPresentationItem **)src_presentation_find_chunk_in_hash_table (
 			    src_presentation_chunks_speech, role, event);
 
-    return *presentation ? TRUE : FALSE;
+    return *presentation && (*presentation)[0] ? TRUE : FALSE;
 }
 
 static gboolean
@@ -614,28 +620,28 @@ srcp_load_pres_for_presentation_for_mag (xmlNode *node,
     xmlNode *crt, *crt2, *crt3;
 
     sru_assert (node && device && hash);
-    srl_assert (xmlStrcmp (node->name, "presentation") == 0);
+    srl_assert (xmlStrcmp (node->name, (const xmlChar*)"presentation") == 0);
 
     for (crt = node->xmlChildrenNode; crt; crt = crt->next)
     {
-	if (xmlStrcmp (crt->name, "role") == 0)
+	if (xmlStrcmp (crt->name, (const xmlChar*)"role") == 0)
 	{
-	    gchar *role = xmlGetProp (crt, "name");
+	    xmlChar *role = xmlGetProp (crt, (const xmlChar*)"name");
 	    for (crt2 = crt->xmlChildrenNode; crt2; crt2 = crt2->next)
 	    {
-		if (xmlStrcmp (crt2->name, "event") == 0)
+		if (xmlStrcmp (crt2->name, (const xmlChar*)"event") == 0)
 		{
-		    gchar *event = xmlGetProp (crt2, "name");
+		    xmlChar *event = xmlGetProp (crt2, (const xmlChar*)"name");
 		    for (crt3 = crt2->xmlChildrenNode; crt3; crt3 = crt3->next)
 		    {
-			if (xmlStrcmp (crt3->name, "bounds") == 0)
+			if (xmlStrcmp (crt3->name, (const xmlChar*)"bounds") == 0)
 			{
-			    gchar *bounds = xmlGetProp (crt3, "type");
-			    gchar *key = g_strconcat (role, "_", event, NULL);
+			    xmlChar *bounds = xmlGetProp (crt3, (const xmlChar*)"type");
+			    gchar *key = g_strconcat ((gchar*)role, "_", (gchar*)event, NULL);
 			    SRCPresentationBoundsType btype = SRC_PRESENTATION_BOUNDS_TYPE_OBJECT;
-			    if (xmlStrcmp (bounds, "text:char") == 0)
+			    if (xmlStrcmp (bounds, (const xmlChar*)"text:char") == 0)
 				btype = SRC_PRESENTATION_BOUNDS_TYPE_TEXT_CHAR;
-			    else if (xmlStrcmp (bounds, "object") == 0)
+			    else if (xmlStrcmp (bounds, (const xmlChar*)"object") == 0)
 				btype = SRC_PRESENTATION_BOUNDS_TYPE_OBJECT;
 			    else
 				sru_warning ("unknown \"%s\" bouds type", bounds);
@@ -660,28 +666,28 @@ srcp_load_pres_for_presentation (xmlNode *node,
     xmlNode *crt;
     
     srl_assert (node && device && hash);
-    srl_assert (xmlStrcmp (node->name, "presentation") == 0);
+    srl_assert (xmlStrcmp (node->name, (const xmlChar*)"presentation") == 0);
 
     for (crt = node->xmlChildrenNode; crt; crt = crt->next)
     {
-	if (xmlStrcmp (crt->name, "role") == 0)
+	if (xmlStrcmp (crt->name, (const xmlChar*)"role") == 0)
 	{
-	    gchar *role;
+	    xmlChar *role;
 	    xmlNode *crt2;
-	    srl_assert (xmlStrcmp (crt->name, "role") == 0);
-	    role = xmlGetProp (crt, "name");
+	    srl_assert (xmlStrcmp (crt->name, (const xmlChar*)"role") == 0);
+	    role = xmlGetProp (crt, (const xmlChar*)"name");
 	    for (crt2 = crt->xmlChildrenNode; crt2; crt2 = crt2->next)
 	    {
-		gchar *event;
+		xmlChar *event;
 		gchar *key;
 		SRCPresentationItem  **pres;
 
-		srl_assert (xmlStrcmp (crt2->name, "event") == 0);
-		event = xmlGetProp (crt2, "name");
+		srl_assert (xmlStrcmp (crt2->name, (const xmlChar*)"event") == 0);
+		event = xmlGetProp (crt2, (const xmlChar*)"name");
 		src_presentation_get_presentation_items_from_node (crt2,
 		    		device, &pres); 
 		/* sru_assert (pres); */
-		key = g_strconcat (role, "_", event, NULL);
+		key = g_strconcat ((gchar*)role, "_", (gchar*)event, NULL);
 		g_hash_table_insert (hash, key, pres);
 	    }
 	}
@@ -705,11 +711,11 @@ srcp_load_pres_from_root_node (xmlNode *rootnode)
 	    xmlChar *name = xmlGetProp (crt, (const xmlChar *) "name");
 	    if (name)
 	    {
-		if (xmlStrcmp (name, "braille") == 0)
+		if (xmlStrcmp (name, (const xmlChar*)"braille") == 0)
 		    srcp_load_pres_for_presentation (crt->xmlChildrenNode, "braille", src_presentation_chunks_braille);
-		else if (xmlStrcmp (name, "speech") == 0)
+		else if (xmlStrcmp (name, (const xmlChar*)"speech") == 0)
 		    srcp_load_pres_for_presentation (crt->xmlChildrenNode, "speech", src_presentation_chunks_speech);
-		else if (xmlStrcmp (name, "magnifier") == 0)
+		else if (xmlStrcmp (name, (const xmlChar*)"magnifier") == 0)
 		    srcp_load_pres_for_presentation_for_mag (crt->xmlChildrenNode, "magnifier", src_presentation_chunks_magnifier);
 		else
 		    sru_warning ("Unknown \"%s\" device", name);
