@@ -25,10 +25,6 @@
 #include "SRObject.h"
 #include "SREvent.h"
 
-#define SR_MOUSE_BUTTON_LEFT	1
-#define SR_MOUSE_BUTTON_RIGHT	2
-
-
 /**
  * SRLClientHandle :
  *
@@ -56,10 +52,6 @@ gboolean srl_init 		();
 gboolean srl_terminate 		();
 SRLClientHandle srl_add_client 	(const SRLClient *client);
 gboolean srl_remove_client 	(SRLClientHandle client_handle);
-gboolean srl_mouse_move 	(gint x, gint y);
-gboolean srl_mouse_click 	(gint button);
-gboolean srl_mouse_button_down 	(gint button);
-gboolean srl_mouse_button_up 	(gint button);
 gboolean srl_set_watch_for_object (SRObject *obj);
 void     srl_unwatch_all_objects ();
 gboolean srl_is_object_watched (SRObject *obj);
